@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Bakerloo;
 
-$Map::Tube::London::Line::Bakerloo::VERSION   = '0.46';
+$Map::Tube::London::Line::Bakerloo::VERSION   = '0.47';
 $Map::Tube::London::Line::Bakerloo::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Bakerloo - London Tube Map Bakerloo Line stations.
 
 =head1 VERSION
 
-Version 0.46
+Version 0.47
 
 =head1 DESCRIPTION
 
@@ -59,7 +59,8 @@ London Tube Map Bakerloo Line stations.
 =item * The station "Paddington" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
-=item * The station "Embankment" is also part of L<District Line|Map::Tube::London::Line::District>.
+=item * The station "Embankment" is also part of L<District Line|Map::Tube::London::Line::District>
+        | L<Northern Line|Map::Tube::London::Line::Northern>.
 
 =item * The station "Baker Street" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
