@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Jubilee;
 
-$Map::Tube::London::Line::Jubilee::VERSION   = '0.46';
+$Map::Tube::London::Line::Jubilee::VERSION   = '0.47';
 $Map::Tube::London::Line::Jubilee::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Jubilee - London Tube Map Jubilee Line stations.
 
 =head1 VERSION
 
-Version 0.46
+Version 0.47
 
 =head1 DESCRIPTION
 
@@ -66,7 +66,7 @@ London Tube Map Jubilee Line stations.
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>.
 
 =item * The station "Waterloo" is also part of L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
-        | Northern Line
+        | L<Northern Line|Map::Tube::London::Line::Northern>
         | Waterloo & City Line.
 
 =item * The station "London Bridge" is also part of Northern Line.
